B2 Utility functions
====================

.. autofunction:: b2sdk.v2.b2_url_encode
.. autofunction:: b2sdk.v2.b2_url_decode
.. autofunction:: b2sdk.v2.choose_part_ranges
.. autofunction:: b2sdk.v2.fix_windows_path_limit
.. autofunction:: b2sdk.v2.format_and_scale_fraction
.. autofunction:: b2sdk.v2.format_and_scale_number
.. autofunction:: b2sdk.v2.hex_sha1_of_stream
.. autofunction:: b2sdk.v2.hex_sha1_of_bytes

.. autoclass:: b2sdk.v2.TempDir()
   :inherited-members:
   :special-members: __enter__, __exit__

